Welcome to networking-generic-switch's documentation!
=====================================================

.. toctree::
   :maxdepth: 2

   supported-devices
   installation
   configuration
   dev/dev-quickstart
   contributing
   contributor/api/modules

Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`
